import React from 'react';
import { BrowserRouter, Routes, Route } from 'react-router-dom';
import { Navigation } from './components/navigation/Navigation';
import { AuthProvider } from './providers/AuthProvider';
import { InboxProvider } from './components/inbox/InboxProvider';
import { BuilderPage } from './pages/BuilderPage';
import { CategoryPage } from './pages/CategoryPage';
import { SharedBuildPage } from './pages/SharedBuildPage';
import { ShareBuildPage } from './pages/ShareBuildPage';
import { RegisterPage } from './pages/RegisterPage';
import { LoginPage } from './pages/LoginPage';
import { ProductDetailsPage } from './pages/ProductDetailsPage';
import { FavoritesPage } from './pages/FavoritesPage';
import { SavedBuildsPage } from './pages/SavedBuildsPage';
import { DashboardPage } from './pages/DashboardPage';
import { ComparePage } from './pages/ComparePage';
import { PriceTrendsPage } from './pages/PriceTrendsPage';
import { ForumPage } from './pages/ForumPage';
import { CommunityBuildsPage } from './pages/CommunityBuildsPage';
import { CommunityBuildDetailsPage } from './pages/CommunityBuildDetailsPage';
import { AccessoriesPage } from './pages/AccessoriesPage';

export default function App() {
  const [selectedProducts, setSelectedProducts] = React.useState([]);

  return (
    <AuthProvider>
      <InboxProvider>
        <BrowserRouter>
          <div className="min-h-screen bg-gray-100">
            <Navigation />
            <Routes>
              <Route 
                path="/" 
                element={
                  <BuilderPage 
                    selectedProducts={selectedProducts}
                    setSelectedProducts={setSelectedProducts}
                  />
                } 
              />
              <Route 
                path="/category/:categoryId" 
                element={
                  <CategoryPage
                    selectedProducts={selectedProducts}
                    setSelectedProducts={setSelectedProducts}
                  />
                }
              />
              <Route 
                path="/build/:hash" 
                element={
                  <SharedBuildPage 
                    setSelectedProducts={setSelectedProducts}
                  />
                }
              />
              <Route 
                path="/share-build" 
                element={
                  <ShareBuildPage 
                    selectedProducts={selectedProducts}
                  />
                }
              />
              <Route path="/register" element={<RegisterPage />} />
              <Route path="/login" element={<LoginPage />} />
              <Route path="/product/:productId" element={<ProductDetailsPage />} />
              <Route 
                path="/favorites" 
                element={
                  <FavoritesPage
                    selectedProducts={selectedProducts}
                    setSelectedProducts={setSelectedProducts}
                  />
                }
              />
              <Route path="/saved-builds" element={<SavedBuildsPage />} />
              <Route path="/dashboard" element={<DashboardPage />} />
              <Route path="/compare" element={<ComparePage />} />
              <Route path="/trends" element={<PriceTrendsPage />} />
              <Route path="/forum/*" element={<ForumPage />} />
              <Route path="/community" element={<CommunityBuildsPage />} />
              <Route path="/community/:buildId" element={<CommunityBuildDetailsPage />} />
              <Route path="/accessories" element={<AccessoriesPage />} />
            </Routes>
          </div>
        </BrowserRouter>
      </InboxProvider>
    </AuthProvider>
  );
}