import React from 'react';
import { History } from 'lucide-react';
import { Modal } from '../Modal';
import { Product } from '../../types';
import { formatDistanceToNow } from '../../utils/date';

interface BuildHistoryModalProps {
  isOpen: boolean;
  onClose: () => void;
  history: Array<{
    product: Product;
    timestamp: string;
    action: 'added' | 'removed';
  }>;
}

export function BuildHistoryModal({ isOpen, onClose, history }: BuildHistoryModalProps) {
  return (
    <Modal isOpen={isOpen} onClose={onClose}>
      <div className="p-6">
        <div className="flex items-center gap-2 mb-6">
          <History className="h-5 w-5 text-gray-600" />
          <h2 className="text-xl font-semibold">Build History</h2>
        </div>

        {history.length === 0 ? (
          <p className="text-gray-500 text-center py-4">No history yet</p>
        ) : (
          <div className="space-y-4">
            {history.map((entry, index) => (
              <div
                key={`${entry.product.id}-${index}`}
                className="flex items-start gap-4 p-4 bg-gray-50 rounded-lg"
              >
                <img
                  src={entry.product.image}
                  alt={entry.product.name}
                  className="w-12 h-12 object-cover rounded"
                />
                <div className="flex-1">
                  <p className="font-medium text-gray-900">{entry.product.name}</p>
                  <p className="text-sm text-gray-600">
                    {entry.action === 'added' ? 'Added to' : 'Removed from'} build
                  </p>
                  <p className="text-sm text-gray-500">
                    {formatDistanceToNow(entry.timestamp)} ago
                  </p>
                </div>
              </div>
            ))}
          </div>
        )}
      </div>
    </Modal>
  );
}