import React from 'react';
import { BuildListHeader } from './BuildListHeader';
import { BuildListRow } from './BuildListRow';
import { BuildListTotal } from './BuildListTotal';
import { Product, ProductCategory } from '../../types';
import { categories } from '../../data/categories';

interface BuildListProps {
  selectedProducts: Product[];
  onRemove: (product: Product) => void;
  onSelectCategory: (category: string) => void;
}

export function BuildList({ selectedProducts, onRemove, onSelectCategory }: BuildListProps) {
  // Group products by category
  const productsByCategory = new Map<ProductCategory, Product>();
  selectedProducts.forEach(product => {
    productsByCategory.set(product.category, product);
  });

  const total = selectedProducts.reduce((sum, product) => sum + product.price, 0);

  return (
    <div className="bg-white rounded-lg shadow-md overflow-hidden">
      <BuildListHeader />
      
      <div className="divide-y divide-gray-200">
        {categories.map(({ label, value }) => (
          <BuildListRow
            key={value}
            category={value}
            categoryLabel={label}
            product={productsByCategory.get(value)}
            onRemove={onRemove}
            onSelect={() => onSelectCategory(value)}
          />
        ))}
      </div>

      <BuildListTotal total={total} />
    </div>
  );
}