import React, { useState } from 'react';
import { Save, Share2, History } from 'lucide-react';
import { ShareBuild } from '../ShareBuild';
import { SaveBuildModal } from './SaveBuildModal';
import { BuildHistoryModal } from './BuildHistoryModal';
import { Product } from '../../types';
import { useAuth } from '../../hooks/useAuth';
import { useNavigate } from 'react-router-dom';
import { useBuildHistory } from '../../hooks/useBuildHistory';

interface BuildListActionsProps {
  selectedProducts: Product[];
}

export function BuildListActions({ selectedProducts }: BuildListActionsProps) {
  const { isAuthenticated } = useAuth();
  const navigate = useNavigate();
  const [isSaveModalOpen, setIsSaveModalOpen] = useState(false);
  const [isHistoryModalOpen, setIsHistoryModalOpen] = useState(false);
  const { history } = useBuildHistory();

  const handleShareBuild = () => {
    navigate('/share-build');
  };

  if (selectedProducts.length === 0) {
    return null;
  }

  return (
    <div className="flex justify-end gap-3 mb-4">
      {isAuthenticated && (
        <>
          <button
            onClick={() => setIsHistoryModalOpen(true)}
            className="inline-flex items-center gap-2 px-4 py-2 bg-white border border-gray-300 rounded-md hover:bg-gray-50"
            title="View build history"
          >
            <History className="h-4 w-4" />
            <span>History</span>
          </button>
          <button
            onClick={() => setIsSaveModalOpen(true)}
            className="inline-flex items-center gap-2 px-4 py-2 bg-white border border-gray-300 rounded-md hover:bg-gray-50"
          >
            <Save className="h-4 w-4" />
            <span>Save Build</span>
          </button>
          <button
            onClick={handleShareBuild}
            className="inline-flex items-center gap-2 px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
          >
            <Share2 className="h-4 w-4" />
            <span>Share with Community</span>
          </button>
        </>
      )}
      <ShareBuild selectedProducts={selectedProducts} />
      
      <SaveBuildModal
        isOpen={isSaveModalOpen}
        onClose={() => setIsSaveModalOpen(false)}
        selectedProducts={selectedProducts}
      />

      <BuildHistoryModal
        isOpen={isHistoryModalOpen}
        onClose={() => setIsHistoryModalOpen(false)}
        history={history}
      />
    </div>
  );
}