import React from 'react';
import { Trash2, ShoppingCart } from 'lucide-react';
import { Product, ProductCategory } from '../../types';

interface BuildListRowProps {
  category: ProductCategory;
  categoryLabel: string;
  product?: Product;
  onRemove: (product: Product) => void;
  onSelect: () => void;
}

export function BuildListRow({ category, categoryLabel, product, onRemove, onSelect }: BuildListRowProps) {
  const handleBuyNow = (e: React.MouseEvent) => {
    e.preventDefault();
    // TODO: Implement buy now functionality
    window.open(`https://example.com/buy/${product?.id}`, '_blank');
  };

  return (
    <div className="px-6 py-4 grid grid-cols-12 gap-4 items-center hover:bg-gray-50">
      <div className="col-span-3">
        <span className="font-medium text-gray-900">{categoryLabel}</span>
      </div>
      
      <div className="col-span-4">
        {product ? (
          <div className="flex items-center gap-2">
            <img 
              src={product.image} 
              alt={product.name}
              className="w-12 h-12 object-cover rounded"
            />
            <div>
              <p className="font-medium text-gray-900">{product.name}</p>
              <p className="text-sm text-gray-600">{product.brand}</p>
            </div>
          </div>
        ) : (
          <button
            onClick={onSelect}
            className="text-blue-600 hover:text-blue-700"
          >
            Choose a {category.replace('_', ' ')}
          </button>
        )}
      </div>

      <div className="col-span-2">
        {product && (
          <span className="font-medium text-gray-900">
            ${product.price.toLocaleString()}
          </span>
        )}
      </div>

      <div className="col-span-3 flex items-center gap-2">
        {product && (
          <>
            <button
              onClick={handleBuyNow}
              className="inline-flex items-center gap-1 px-3 py-1.5 bg-green-600 text-white text-sm font-medium rounded-md hover:bg-green-700"
            >
              <ShoppingCart className="h-4 w-4" />
              Buy Now
            </button>
            <button
              onClick={() => onRemove(product)}
              className="p-1.5 text-red-600 hover:bg-red-50 rounded-md"
              title="Remove from build"
            >
              <Trash2 className="h-4 w-4" />
            </button>
          </>
        )}
      </div>
    </div>
  );
}