import React, { useState } from 'react';
import { Save } from 'lucide-react';
import { useAuth } from '../../hooks/useAuth';
import { useSavedBuilds } from '../../hooks/useSavedBuilds';
import { Product } from '../../types';
import { Modal } from '../Modal';

interface SaveBuildButtonProps {
  selectedProducts: Product[];
}

export function SaveBuildButton({ selectedProducts }: SaveBuildButtonProps) {
  const { isAuthenticated } = useAuth();
  const { saveBuild } = useSavedBuilds();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [buildName, setBuildName] = useState('');
  const [error, setError] = useState('');

  if (!isAuthenticated || selectedProducts.length === 0) return null;

  const handleSave = () => {
    if (!buildName.trim()) {
      setError('Please enter a name for your build');
      return;
    }

    saveBuild(buildName.trim(), selectedProducts);
    setIsModalOpen(false);
    setBuildName('');
    setError('');
  };

  return (
    <>
      <button
        onClick={() => setIsModalOpen(true)}
        className="inline-flex items-center gap-2 px-4 py-2 bg-white border border-gray-300 rounded-md hover:bg-gray-50"
      >
        <Save className="h-4 w-4" />
        <span>Save Build</span>
      </button>

      <Modal isOpen={isModalOpen} onClose={() => setIsModalOpen(false)}>
        <div className="p-6">
          <h2 className="text-xl font-semibold mb-4">Save Build</h2>
          <div className="space-y-4">
            <div>
              <label className="block text-sm font-medium text-gray-700 mb-1">
                Build Name
              </label>
              <input
                type="text"
                value={buildName}
                onChange={(e) => {
                  setBuildName(e.target.value);
                  setError('');
                }}
                className="w-full px-3 py-2 border rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
                placeholder="Enter a name for your build"
              />
              {error && (
                <p className="mt-1 text-sm text-red-600">{error}</p>
              )}
            </div>

            <div className="flex justify-end gap-3">
              <button
                onClick={() => setIsModalOpen(false)}
                className="px-4 py-2 text-gray-700 hover:text-gray-900"
              >
                Cancel
              </button>
              <button
                onClick={handleSave}
                className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
              >
                Save Build
              </button>
            </div>
          </div>
        </div>
      </Modal>
    </>
  );
}