import React, { useState } from 'react';
import { Modal } from '../Modal';
import { useSavedBuilds } from '../../hooks/useSavedBuilds';
import { Product } from '../../types';

interface SaveBuildModalProps {
  isOpen: boolean;
  onClose: () => void;
  selectedProducts: Product[];
}

export function SaveBuildModal({ isOpen, onClose, selectedProducts }: SaveBuildModalProps) {
  const [buildName, setBuildName] = useState('');
  const [error, setError] = useState('');
  const { saveBuild } = useSavedBuilds();

  const handleSave = () => {
    if (!buildName.trim()) {
      setError('Please enter a name for your build');
      return;
    }

    saveBuild(buildName.trim(), selectedProducts);
    setBuildName('');
    setError('');
    onClose();
  };

  return (
    <Modal isOpen={isOpen} onClose={onClose}>
      <div className="p-6">
        <h2 className="text-xl font-semibold mb-4">Save Build</h2>
        <div className="space-y-4">
          <div>
            <label className="block text-sm font-medium text-gray-700 mb-1">
              Build Name
            </label>
            <input
              type="text"
              value={buildName}
              onChange={(e) => {
                setBuildName(e.target.value);
                setError('');
              }}
              className="w-full px-3 py-2 border rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
              placeholder="Enter a name for your build"
            />
            {error && (
              <p className="mt-1 text-sm text-red-600">{error}</p>
            )}
          </div>

          <div className="flex justify-end gap-3">
            <button
              onClick={onClose}
              className="px-4 py-2 text-gray-700 hover:text-gray-900"
            >
              Cancel
            </button>
            <button
              onClick={handleSave}
              className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
            >
              Save Build
            </button>
          </div>
        </div>
      </div>
    </Modal>
  );
}