import React from 'react';
import { Trash2 } from 'lucide-react';
import { Product } from '../types';

interface BuildSummaryProps {
  selectedProducts: Product[];
  onRemove: (product: Product) => void;
}

export function BuildSummary({ selectedProducts, onRemove }: BuildSummaryProps) {
  const total = selectedProducts.reduce((sum, product) => sum + product.price, 0);

  return (
    <div className="bg-white rounded-lg shadow-md p-4">
      <h2 className="text-lg font-semibold mb-4">Current Build</h2>
      
      {selectedProducts.length === 0 ? (
        <p className="text-gray-500">No parts selected yet</p>
      ) : (
        <div className="space-y-4">
          {selectedProducts.map((product) => (
            <div key={product.id} className="flex items-center justify-between">
              <div>
                <p className="font-medium">{product.name}</p>
                <p className="text-sm text-gray-600">${product.price.toLocaleString()}</p>
              </div>
              <button
                onClick={() => onRemove(product)}
                className="p-1 hover:bg-red-100 rounded-full text-red-600"
              >
                <Trash2 className="h-4 w-4" />
              </button>
            </div>
          ))}
          
          <div className="pt-4 border-t">
            <div className="flex justify-between items-center">
              <span className="font-semibold">Total:</span>
              <span className="font-bold text-lg">
                ${total.toLocaleString()}
              </span>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}