import React, { useState } from 'react';
import { Heart } from 'lucide-react';
import { useAuth } from '../hooks/useAuth';
import { useFavorites } from '../hooks/useFavorites';
import { Product } from '../types';
import { AuthModal } from './auth/AuthModal';

interface FavoriteButtonProps {
  product: Product;
  size?: 'sm' | 'md';
}

export function FavoriteButton({ product, size = 'md' }: FavoriteButtonProps) {
  const { isAuthenticated } = useAuth();
  const { favorites, toggleFavorite } = useFavorites();
  const [showAuthModal, setShowAuthModal] = useState(false);
  const isFavorite = favorites.some(f => f.id === product.id);

  const handleClick = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    
    if (!isAuthenticated) {
      setShowAuthModal(true);
      return;
    }
    
    toggleFavorite(product);
  };

  const sizeClasses = {
    sm: 'p-1.5',
    md: 'p-2'
  };

  const iconSizes = {
    sm: 'h-4 w-4',
    md: 'h-5 w-5'
  };

  return (
    <>
      <button
        onClick={handleClick}
        className={`${sizeClasses[size]} rounded-full transition-colors ${
          isFavorite 
            ? 'text-red-600 hover:bg-red-50' 
            : 'text-gray-400 hover:bg-gray-50 hover:text-gray-500'
        }`}
        title={isAuthenticated ? (isFavorite ? 'Remove from favorites' : 'Add to favorites') : 'Sign in to add to favorites'}
      >
        <Heart
          className={`${iconSizes[size]} ${isFavorite ? 'fill-current' : ''}`}
        />
      </button>

      <AuthModal 
        isOpen={showAuthModal} 
        onClose={() => setShowAuthModal(false)} 
      />
    </>
  );
}