import React from 'react';
import { categories } from '../data/categories';
import { PriceFilter } from './PriceFilter';
import { ProductCategory } from '../types';

interface FiltersProps {
  selectedCategory: ProductCategory | null;
  onCategoryChange: (category: ProductCategory | null) => void;
  minPrice: number;
  maxPrice: number;
  onPriceChange: (min: number, max: number) => void;
}

export function Filters({ 
  selectedCategory, 
  onCategoryChange,
  minPrice,
  maxPrice,
  onPriceChange
}: FiltersProps) {
  return (
    <div className="space-y-4">
      <div className="bg-white p-4 rounded-lg shadow-md">
        <h2 className="text-lg font-semibold mb-4">Categories</h2>
        <div className="space-y-2">
          {categories.map(({ label, value }) => (
            <button
              key={value}
              onClick={() => onCategoryChange(selectedCategory === value ? null : value)}
              className={`w-full text-left px-3 py-2 rounded-md transition-colors ${
                selectedCategory === value
                  ? 'bg-blue-100 text-blue-700'
                  : 'hover:bg-gray-100'
              }`}
            >
              {label}
            </button>
          ))}
        </div>
      </div>
      
      <PriceFilter
        minPrice={minPrice}
        maxPrice={maxPrice}
        onPriceChange={onPriceChange}
      />
    </div>
  );
}