import React from 'react';

interface BrandFilterProps {
  brands: string[];
  selectedBrands: string[];
  onChange: (brands: string[]) => void;
}

export function BrandFilter({ brands, selectedBrands, onChange }: BrandFilterProps) {
  const toggleBrand = (brand: string) => {
    if (selectedBrands.includes(brand)) {
      onChange(selectedBrands.filter(b => b !== brand));
    } else {
      onChange([...selectedBrands, brand]);
    }
  };

  return (
    <div className="bg-white p-4 rounded-lg shadow-md">
      <h2 className="text-lg font-semibold mb-4">Brands</h2>
      <div className="space-y-2">
        {brands.map(brand => (
          <label key={brand} className="flex items-center gap-2">
            <input
              type="checkbox"
              checked={selectedBrands.includes(brand)}
              onChange={() => toggleBrand(brand)}
              className="rounded border-gray-300 text-blue-600 focus:ring-blue-500"
            />
            <span className="text-gray-700">{brand}</span>
          </label>
        ))}
      </div>
    </div>
  );
}