import React from 'react';

interface PriceFilterProps {
  minPrice: number;
  maxPrice: number;
  onPriceChange: (min: number, max: number) => void;
}

export function PriceFilter({ minPrice, maxPrice, onPriceChange }: PriceFilterProps) {
  const priceRanges = [
    { min: 0, max: 1000, label: 'Under $1,000' },
    { min: 1000, max: 2000, label: '$1,000 - $2,000' },
    { min: 2000, max: 3000, label: '$2,000 - $3,000' },
    { min: 3000, max: 5000, label: '$3,000 - $5,000' },
    { min: 5000, max: Infinity, label: '$5,000+' }
  ];

  return (
    <div className="bg-white p-4 rounded-lg shadow-md mt-4">
      <h2 className="text-lg font-semibold mb-4">Price Range</h2>
      <div className="space-y-2">
        {priceRanges.map(({ min, max, label }) => (
          <button
            key={label}
            onClick={() => onPriceChange(min, max)}
            className={`w-full text-left px-3 py-2 rounded-md transition-colors ${
              minPrice === min && maxPrice === max
                ? 'bg-blue-100 text-blue-700'
                : 'hover:bg-gray-100'
            }`}
          >
            {label}
          </button>
        ))}
      </div>
    </div>
  );
}