import React from 'react';
import { Product } from '../types';
import { FavoriteButton } from './FavoriteButton';
import { useCompare } from '../hooks/useCompare';

interface ProductCardProps {
  product: Product;
  onSelect: (product: Product) => void;
  showCompare?: boolean;
}

export function ProductCard({ product, onSelect, showCompare = true }: ProductCardProps) {
  const { toggleCompare, isInComparison } = useCompare();

  const handleCompare = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    toggleCompare(product);
  };

  return (
    <div className="bg-white rounded-lg shadow-md p-4">
      <div className="flex gap-4">
        <img 
          src={product.image} 
          alt={product.name}
          className="w-24 h-24 object-cover rounded-lg"
        />
        <div className="flex-1">
          <div className="flex justify-between items-start">
            <div>
              <h3 className="font-medium text-gray-900">{product.name}</h3>
              <p className="text-sm text-gray-600">{product.brand}</p>
              <p className="text-sm text-gray-600 mt-1">{product.description}</p>
            </div>
            <div className="flex items-center gap-2">
              <FavoriteButton product={product} size="sm" />
              {showCompare && (
                <label className="relative flex items-center cursor-pointer">
                  <input
                    type="checkbox"
                    className="w-4 h-4 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500"
                    checked={isInComparison(product.id)}
                    onChange={handleCompare}
                  />
                  <span className="sr-only">Add to compare</span>
                </label>
              )}
            </div>
          </div>
          
          <div className="flex justify-between items-center mt-4">
            <span className="font-medium text-gray-900">
              ${product.price.toLocaleString()}
            </span>
            <button
              onClick={() => onSelect(product)}
              className="px-3 py-1.5 bg-blue-600 text-white text-sm rounded-md hover:bg-blue-700"
            >
              Select
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}