import React from 'react';
import { Product } from '../types';

interface ProductDetailsProps {
  product: Product;
}

export function ProductDetails({ product }: ProductDetailsProps) {
  return (
    <div className="p-6">
      <div className="flex gap-6">
        <img
          src={product.image}
          alt={product.name}
          className="w-1/3 h-48 object-cover rounded-lg"
        />
        <div>
          <h2 className="text-2xl font-bold">{product.name}</h2>
          <p className="text-gray-600">{product.brand}</p>
          <p className="text-xl font-bold mt-2">${product.price.toLocaleString()}</p>
          <p className="mt-2 text-gray-700">{product.description}</p>
        </div>
      </div>

      <div className="mt-6">
        <h3 className="text-lg font-semibold mb-3">Specifications</h3>
        <dl className="grid grid-cols-2 gap-4">
          {Object.entries(product.specs).map(([key, value]) => (
            <div key={key} className="bg-gray-50 p-3 rounded-lg">
              <dt className="text-sm text-gray-600">{key}</dt>
              <dd className="font-medium">{value}</dd>
            </div>
          ))}
        </dl>
      </div>
    </div>
  );
}