import React from 'react';
import { ProductTableHeader } from './ProductTableHeader';
import { ProductTableRow } from './ProductTableRow';
import { Product } from '../../types';
import { useCompare } from '../../hooks/useCompare';
import { useNavigate } from 'react-router-dom';

interface ProductTableProps {
  products: Product[];
  onSelect: (product: Product) => void;
}

export function ProductTable({ products, onSelect }: ProductTableProps) {
  const { products: compareProducts } = useCompare();
  const navigate = useNavigate();

  return (
    <div className="bg-white rounded-lg shadow-md overflow-hidden">
      {compareProducts.length >= 2 && (
        <div className="p-4 border-b border-gray-200">
          <button
            onClick={() => navigate('/compare')}
            className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700 transition-colors"
          >
            Compare {compareProducts.length} Products
          </button>
        </div>
      )}
      <ProductTableHeader />
      <div className="divide-y divide-gray-200">
        {products.map(product => (
          <ProductTableRow
            key={product.id}
            product={product}
            onSelect={onSelect}
          />
        ))}
      </div>
    </div>
  );
}