import React, { useState } from 'react';
import { Share2, Copy, Facebook, Twitter, MessageCircle, Mail, Check } from 'lucide-react';
import { encodeBuild } from '../utils/buildShare';
import { Product } from '../types';
import { Modal } from './Modal';

interface ShareBuildProps {
  selectedProducts: Product[];
}

export function ShareBuild({ selectedProducts }: ShareBuildProps) {
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [copied, setCopied] = useState(false);

  const buildUrl = `${window.location.origin}/build/${encodeBuild(selectedProducts)}`;

  const handleCopy = async () => {
    try {
      await navigator.clipboard.writeText(buildUrl);
      setCopied(true);
      setTimeout(() => setCopied(false), 2000);
    } catch (err) {
      console.error('Failed to copy URL:', err);
    }
  };

  const shareLinks = {
    facebook: `https://www.facebook.com/sharer/sharer.php?u=${encodeURIComponent(buildUrl)}`,
    twitter: `https://twitter.com/intent/tweet?url=${encodeURIComponent(buildUrl)}&text=${encodeURIComponent('Check out my golf simulator build!')}`,
    message: `sms:?body=${encodeURIComponent(`Check out my golf simulator build! ${buildUrl}`)}`,
    email: `mailto:?subject=${encodeURIComponent('Golf Simulator Build')}&body=${encodeURIComponent(`Check out my golf simulator build! ${buildUrl}`)}`
  };

  return (
    <>
      <button
        onClick={() => setIsModalOpen(true)}
        className="inline-flex items-center gap-2 px-4 py-2 bg-white border border-gray-300 rounded-md hover:bg-gray-50"
      >
        <Share2 className="h-4 w-4" />
        <span>Share Link</span>
      </button>

      <Modal isOpen={isModalOpen} onClose={() => setIsModalOpen(false)}>
        <div className="p-6">
          <h2 className="text-xl font-semibold mb-6">Share Build</h2>
          
          <div className="space-y-6">
            {/* Copy Link */}
            <div className="flex items-center gap-3">
              <div className="flex-1 bg-gray-50 rounded-lg overflow-hidden">
                <input
                  type="text"
                  value={buildUrl}
                  readOnly
                  className="w-full px-3 py-2 bg-transparent"
                />
              </div>
              <button
                onClick={handleCopy}
                className="flex items-center gap-2 px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
              >
                {copied ? (
                  <>
                    <Check className="h-4 w-4" />
                    <span>Copied!</span>
                  </>
                ) : (
                  <>
                    <Copy className="h-4 w-4" />
                    <span>Copy</span>
                  </>
                )}
              </button>
            </div>

            {/* Social Share Buttons */}
            <div>
              <p className="text-sm text-gray-600 mb-3">Share on social media</p>
              <div className="flex gap-3">
                <a
                  href={shareLinks.facebook}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="p-3 bg-blue-600 text-white rounded-full hover:bg-blue-700"
                >
                  <Facebook className="h-5 w-5" />
                </a>
                <a
                  href={shareLinks.twitter}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="p-3 bg-sky-500 text-white rounded-full hover:bg-sky-600"
                >
                  <Twitter className="h-5 w-5" />
                </a>
                <a
                  href={shareLinks.message}
                  className="p-3 bg-green-500 text-white rounded-full hover:bg-green-600"
                >
                  <MessageCircle className="h-5 w-5" />
                </a>
                <a
                  href={shareLinks.email}
                  className="p-3 bg-gray-600 text-white rounded-full hover:bg-gray-700"
                >
                  <Mail className="h-5 w-5" />
                </a>
              </div>
            </div>
          </div>
        </div>
      </Modal>
    </>
  );
}