import React from 'react';
import { Wrench } from 'lucide-react';
import { Accessory } from '../../types/accessory';
import { FavoriteButton } from '../FavoriteButton';

interface AccessoryCardProps {
  accessory: Accessory;
}

export function AccessoryCard({ accessory }: AccessoryCardProps) {
  return (
    <div className="bg-white rounded-lg shadow-md overflow-hidden">
      <div className="aspect-video relative">
        <img 
          src={accessory.image} 
          alt={accessory.name}
          className="w-full h-full object-cover"
        />
        <div className="absolute top-2 right-2">
          <FavoriteButton product={accessory} />
        </div>
      </div>

      <div className="p-4">
        <div className="flex justify-between items-start mb-2">
          <div>
            <h3 className="text-lg font-semibold text-gray-900">{accessory.name}</h3>
            <p className="text-sm text-gray-600">{accessory.brand}</p>
          </div>
          <span className="text-lg font-bold text-gray-900">
            ${accessory.price.toLocaleString()}
          </span>
        </div>

        <p className="text-sm text-gray-600 mb-4">{accessory.description}</p>

        <div className="space-y-2">
          {Object.entries(accessory.specs).map(([key, value]) => (
            <div key={key} className="flex items-center text-sm">
              <span className="text-gray-600 w-24">{key}:</span>
              <span className="text-gray-900">{value}</span>
            </div>
          ))}
        </div>

        <div className="mt-4 flex items-center gap-2 text-sm text-gray-600">
          <Wrench className="h-4 w-4" />
          <span>Installation: {accessory.installationType}</span>
        </div>

        <button className="mt-4 w-full bg-blue-600 text-white py-2 px-4 rounded-md hover:bg-blue-700 transition-colors">
          Add to Cart
        </button>
      </div>
    </div>
  );
}