import React from 'react';
import { Link } from 'react-router-dom';
import { useLoginForm } from '../../hooks/useLoginForm';
import { FormInput } from './FormInput';
import { FormError } from './FormError';

export function LoginForm() {
  const {
    formData,
    errors,
    handleChange,
    handleSubmit,
    isSubmitting
  } = useLoginForm();

  return (
    <div className="space-y-6">
      <form onSubmit={handleSubmit} className="bg-white p-8 rounded-lg shadow-md">
        <div className="space-y-6">
          <FormInput
            label="Email"
            name="email"
            type="email"
            value={formData.email}
            onChange={handleChange}
            error={errors.email}
            autoComplete="email"
            required
          />

          <FormInput
            label="Password"
            name="password"
            type="password"
            value={formData.password}
            onChange={handleChange}
            error={errors.password}
            autoComplete="current-password"
            required
          />

          {errors.form && <FormError message={errors.form} />}

          <button
            type="submit"
            disabled={isSubmitting}
            className="w-full py-3 px-4 bg-blue-600 text-white rounded-md hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 disabled:opacity-50"
          >
            {isSubmitting ? 'Signing In...' : 'Sign In'}
          </button>

          <div className="text-sm">
            <Link
              to="/forgot-password"
              className="text-blue-600 hover:text-blue-700"
            >
              Forgot your password?
            </Link>
          </div>
        </div>
      </form>

      {/* Test Account Info */}
      <div className="bg-gray-50 p-6 rounded-lg border border-gray-200">
        <h3 className="text-sm font-medium text-gray-900 mb-2">Test Account</h3>
        <div className="space-y-1 text-sm text-gray-600">
          <p>Email: test@example.com</p>
          <p>Password: Test123!</p>
        </div>
      </div>
    </div>
  );
}