import React from 'react';
import { Link } from 'react-router-dom';
import { Heart, MessageSquare } from 'lucide-react';
import { CommunityBuild } from '../../types/community';
import { formatDistanceToNow } from '../../utils/date';

interface BuildCardProps {
  build: CommunityBuild;
}

export function BuildCard({ build }: BuildCardProps) {
  const total = build.products.reduce((sum, p) => sum + p.price, 0);

  // Get the first available image from either the build image or the first product's image
  const displayImage = build.image || build.products[0]?.image || 'https://images.unsplash.com/photo-1592595896616-c37162298647?auto=format&fit=crop&q=80&w=2070';

  return (
    <div className="bg-white rounded-lg shadow-md overflow-hidden">
      <div className="aspect-video relative">
        <img 
          src={displayImage}
          alt={build.title}
          className="w-full h-full object-cover"
        />
        <div className="absolute inset-0 bg-gradient-to-t from-black/60 via-black/30 to-transparent" />
        <div className="absolute bottom-0 left-0 right-0 p-4">
          <h3 className="text-lg font-semibold text-white">{build.title}</h3>
          <p className="text-sm text-gray-200">by {build.author.username}</p>
        </div>
      </div>

      <div className="p-4">
        <div className="flex flex-wrap gap-2 mb-4">
          {build.tags.map(tag => (
            <span 
              key={tag}
              className="px-2 py-1 text-xs font-medium bg-blue-100 text-blue-800 rounded-full"
            >
              {tag}
            </span>
          ))}
        </div>

        <p className="text-sm text-gray-600 mb-4 line-clamp-2">
          {build.description}
        </p>

        <div className="flex items-center justify-between text-sm text-gray-500">
          <div className="flex items-center gap-4">
            <span className="flex items-center gap-1">
              <Heart className="h-4 w-4" />
              {build.likes}
            </span>
            <span className="flex items-center gap-1">
              <MessageSquare className="h-4 w-4" />
              {build.comments}
            </span>
          </div>
          <span className="font-medium text-gray-900">
            ${total.toLocaleString()}
          </span>
        </div>

        <Link
          to={`/community/${build.id}`}
          className="mt-4 block w-full text-center py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
        >
          View Build
        </Link>
      </div>
    </div>
  );
}