import React from 'react';
import { BuildFilters as FilterType } from '../../types/community';

interface BuildFiltersProps {
  filters: FilterType;
  onChange: (filters: FilterType) => void;
}

export function BuildFilters({ filters, onChange }: BuildFiltersProps) {
  const priceRanges = [
    { label: 'Under $5,000', min: 0, max: 5000 },
    { label: '$5,000 - $10,000', min: 5000, max: 10000 },
    { label: '$10,000 - $20,000', min: 10000, max: 20000 },
    { label: 'Over $20,000', min: 20000, max: Infinity }
  ];

  return (
    <div className="space-y-6">
      <div className="bg-white p-4 rounded-lg shadow-md">
        <h3 className="font-medium mb-4">Sort By</h3>
        <select
          value={filters.sort}
          onChange={(e) => onChange({ ...filters, sort: e.target.value })}
          className="w-full rounded-md border-gray-300"
        >
          <option value="recent">Most Recent</option>
          <option value="popular">Most Popular</option>
          <option value="budget">Budget Friendly</option>
          <option value="premium">Premium Builds</option>
        </select>
      </div>

      <div className="bg-white p-4 rounded-lg shadow-md">
        <h3 className="font-medium mb-4">Price Range</h3>
        <div className="space-y-2">
          {priceRanges.map(range => (
            <button
              key={range.label}
              onClick={() => onChange({
                ...filters,
                minPrice: range.min,
                maxPrice: range.max
              })}
              className={`w-full text-left px-3 py-2 rounded-md transition-colors ${
                filters.minPrice === range.min && filters.maxPrice === range.max
                  ? 'bg-blue-100 text-blue-700'
                  : 'hover:bg-gray-100'
              }`}
            >
              {range.label}
            </button>
          ))}
        </div>
      </div>

      <div className="bg-white p-4 rounded-lg shadow-md">
        <h3 className="font-medium mb-4">Tags</h3>
        <div className="space-y-2">
          {['Budget', 'Premium', 'Compact', 'Commercial'].map(tag => (
            <label key={tag} className="flex items-center">
              <input
                type="checkbox"
                checked={filters.tags.includes(tag)}
                onChange={(e) => {
                  const newTags = e.target.checked
                    ? [...filters.tags, tag]
                    : filters.tags.filter(t => t !== tag);
                  onChange({ ...filters, tags: newTags });
                }}
                className="rounded border-gray-300 text-blue-600 focus:ring-blue-500"
              />
              <span className="ml-2 text-sm text-gray-600">{tag}</span>
            </label>
          ))}
        </div>
      </div>
    </div>
  );
}