import React from 'react';
import { BuildCard } from './BuildCard';
import { CommunityBuild } from '../../types/community';

interface BuildGridProps {
  builds: CommunityBuild[];
  isLoading: boolean;
}

export function BuildGrid({ builds, isLoading }: BuildGridProps) {
  if (isLoading) {
    return (
      <div className="grid grid-cols-2 gap-6">
        {[1, 2, 3, 4].map(i => (
          <div key={i} className="animate-pulse">
            <div className="bg-gray-200 aspect-video rounded-lg mb-4" />
            <div className="space-y-3">
              <div className="h-6 bg-gray-200 rounded w-3/4" />
              <div className="h-4 bg-gray-200 rounded w-1/2" />
            </div>
          </div>
        ))}
      </div>
    );
  }

  if (builds.length === 0) {
    return (
      <div className="text-center py-12">
        <p className="text-gray-500">No builds found</p>
      </div>
    );
  }

  return (
    <div className="grid grid-cols-2 gap-6">
      {builds.map(build => (
        <BuildCard key={build.id} build={build} />
      ))}
    </div>
  );
}