import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { Scale } from 'lucide-react';
import { useCompare } from '../../hooks/useCompare';
import { Product } from '../../types';
import { Toast } from '../ui/Toast';

interface CompareButtonProps {
  product: Product;
  size?: 'sm' | 'md';
}

export function CompareButton({ product, size = 'md' }: CompareButtonProps) {
  const navigate = useNavigate();
  const { toggleCompare, isInComparison } = useCompare();
  const [error, setError] = useState<string | null>(null);
  
  const sizeClasses = {
    sm: 'p-1.5',
    md: 'p-2'
  };

  const iconSizes = {
    sm: 'h-4 w-4',
    md: 'h-5 w-5'
  };

  const handleCompare = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    const error = toggleCompare(product);
    if (error) {
      setError(error);
      setTimeout(() => setError(null), 3000);
    } else {
      navigate('/compare');
    }
  };

  return (
    <>
      <button
        onClick={handleCompare}
        className={`${sizeClasses[size]} rounded-full transition-colors ${
          isInComparison(product.id)
            ? 'text-blue-600 bg-blue-50 hover:bg-blue-100'
            : 'text-gray-400 hover:bg-gray-50 hover:text-gray-500'
        }`}
        title={isInComparison(product.id) ? 'Remove from comparison' : 'Add to comparison'}
      >
        <Scale className={iconSizes[size]} />
      </button>

      {error && <Toast message={error} type="error" />}
    </>
  );
}