import React from 'react';
import { useNavigate } from 'react-router-dom';
import { Plus, Scale } from 'lucide-react';
import { useCompare } from '../../hooks/useCompare';

export function CompareHeader() {
  const navigate = useNavigate();
  const { products, clearComparison } = useCompare();

  const handleAddProduct = () => {
    if (products.length > 0) {
      navigate(`/category/${products[0].category}`);
    } else {
      navigate('/category/launch_monitor');
    }
  };

  return (
    <div className="bg-white rounded-lg shadow-md p-4 mb-6">
      <div className="flex items-center justify-between">
        <div className="flex items-center gap-3">
          <Scale className="h-5 w-5 text-blue-600" />
          <div>
            <h2 className="font-medium text-gray-900">
              Comparing {products.length} {products[0].category.replace('_', ' ')}
              {products.length > 1 ? 's' : ''}
            </h2>
            <p className="text-sm text-gray-600">
              {4 - products.length} more product{4 - products.length > 1 ? 's' : ''} can be added
            </p>
          </div>
        </div>
        
        <div className="flex items-center gap-2">
          <button
            onClick={handleAddProduct}
            className="flex items-center gap-2 px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
          >
            <Plus className="h-4 w-4" />
            Add Product
          </button>
          <button
            onClick={clearComparison}
            className="px-4 py-2 text-gray-700 hover:text-gray-900"
          >
            Clear All
          </button>
        </div>
      </div>
    </div>
  );
}