import React from 'react';
import { Scale, Plus } from 'lucide-react';
import { useCompareMode } from '../../hooks/useCompareMode';
import { useCompare } from '../../hooks/useCompare';
import { useNavigate } from 'react-router-dom';

export function CompareToggle() {
  const { isActive, toggleMode } = useCompareMode();
  const { products } = useCompare();
  const navigate = useNavigate();

  const handleAddProduct = () => {
    if (products.length > 0) {
      // Navigate to the category of the first product
      navigate(`/category/${products[0].category}`);
    } else {
      // If no products selected, navigate to launch monitors as default
      navigate('/category/launch_monitor');
    }
    if (!isActive) {
      toggleMode();
    }
  };

  return (
    <div className="fixed bottom-4 right-4 z-40 flex items-center gap-2">
      {products.length > 0 && (
        <button
          onClick={handleAddProduct}
          className="bg-blue-600 text-white p-3 rounded-full shadow-lg hover:bg-blue-700"
          title="Add product to compare"
        >
          <Plus className="h-5 w-5" />
        </button>
      )}
      
      <button
        onClick={toggleMode}
        className={`
          p-3 rounded-full shadow-lg
          flex items-center gap-2
          ${isActive ? 'bg-blue-600 text-white' : 'bg-white text-gray-700'}
          transition-colors
        `}
      >
        <Scale className="h-5 w-5" />
        <span className="text-sm font-medium">
          {isActive ? 'Exit Compare' : 'Compare'}
          {products.length > 0 && ` (${products.length})`}
        </span>
      </button>
    </div>
  );
}