import React from 'react';
import { MessageSquare } from 'lucide-react';
import { Link } from 'react-router-dom';
import { useForumStore } from '../../stores/forumStore';
import { useAuth } from '../../hooks/useAuth';
import { formatDistanceToNow } from '../../utils/date';

export function ForumActivityList() {
  const { user } = useAuth();
  const { threads, replies } = useForumStore();

  const userThreads = threads.filter(thread => thread.author.id === user?.id);
  const userReplies = Object.values(replies)
    .flat()
    .filter(reply => reply.author.id === user?.id);

  const activity = [
    ...userThreads.map(thread => ({
      id: thread.id,
      type: 'thread' as const,
      title: thread.title,
      date: thread.createdAt,
      url: `/forum/thread/${thread.id}`
    })),
    ...userReplies.map(reply => ({
      id: reply.id,
      type: 'reply' as const,
      threadId: reply.threadId,
      content: reply.content,
      date: reply.createdAt,
      url: `/forum/thread/${reply.threadId}`
    }))
  ].sort((a, b) => new Date(b.date).getTime() - new Date(a.date).getTime());

  if (activity.length === 0) {
    return (
      <div className="bg-white rounded-lg shadow-md p-6">
        <div className="text-center">
          <MessageSquare className="h-8 w-8 text-gray-400 mx-auto mb-3" />
          <h3 className="text-lg font-medium text-gray-900 mb-1">No Forum Activity</h3>
          <p className="text-gray-500">You haven't posted any threads or replies yet.</p>
        </div>
      </div>
    );
  }

  return (
    <div className="bg-white rounded-lg shadow-md divide-y">
      {activity.map(item => (
        <Link
          key={item.id}
          to={item.url}
          className="block p-4 hover:bg-gray-50"
        >
          <div className="flex items-start justify-between">
            <div>
              {item.type === 'thread' ? (
                <div className="font-medium text-gray-900">
                  Started thread: {item.title}
                </div>
              ) : (
                <div className="font-medium text-gray-900">
                  Replied to thread
                </div>
              )}
              <div className="text-sm text-gray-500 mt-1">
                {formatDistanceToNow(item.date)}
              </div>
            </div>
            <MessageSquare className="h-5 w-5 text-gray-400" />
          </div>
        </Link>
      ))}
    </div>
  );
}