import React from 'react';
import { Bell, Trash2, ToggleLeft, ToggleRight } from 'lucide-react';
import { usePriceAlertStore } from '../../stores/priceAlertStore';
import { useAuth } from '../../hooks/useAuth';
import { products } from '../../data/products';

export function PriceAlertsList() {
  const { user } = useAuth();
  const { alerts, removeAlert, toggleAlert } = usePriceAlertStore();

  const userAlerts = alerts.filter(alert => alert.userId === user?.id);

  if (userAlerts.length === 0) {
    return (
      <div className="bg-white rounded-lg shadow-md p-6">
        <div className="text-center">
          <Bell className="h-8 w-8 text-gray-400 mx-auto mb-3" />
          <h3 className="text-lg font-medium text-gray-900 mb-1">No Price Alerts</h3>
          <p className="text-gray-500">You haven't set any price alerts yet.</p>
        </div>
      </div>
    );
  }

  return (
    <div className="bg-white rounded-lg shadow-md divide-y">
      {userAlerts.map(alert => {
        const product = products.find(p => p.id === alert.productId);
        if (!product) return null;

        return (
          <div key={alert.id} className="p-4 flex items-center justify-between">
            <div>
              <div className="font-medium text-gray-900">{product.name}</div>
              <div className="text-sm text-gray-500">
                Alert when price {alert.type === 'decrease' ? 'drops below' : 'rises above'} ${alert.targetPrice.toLocaleString()}
              </div>
            </div>
            <div className="flex items-center gap-3">
              <button
                onClick={() => toggleAlert(alert.id)}
                className="text-gray-600 hover:text-gray-900"
                title={alert.isActive ? 'Deactivate alert' : 'Activate alert'}
              >
                {alert.isActive ? (
                  <ToggleRight className="h-6 w-6 text-blue-600" />
                ) : (
                  <ToggleLeft className="h-6 w-6" />
                )}
              </button>
              <button
                onClick={() => removeAlert(alert.id)}
                className="text-gray-600 hover:text-red-600"
                title="Remove alert"
              >
                <Trash2 className="h-5 w-5" />
              </button>
            </div>
          </div>
        );
      })}
    </div>
  );
}