import React from 'react';
import { useNavigate } from 'react-router-dom';
import { Trash2, Edit2, Share2 } from 'lucide-react';
import { SavedBuild } from '../../hooks/useSavedBuilds';
import { useSavedBuilds } from '../../hooks/useSavedBuilds';
import { encodeBuild } from '../../utils/buildShare';

interface SavedBuildCardProps {
  build: SavedBuild;
}

export function SavedBuildCard({ build }: SavedBuildCardProps) {
  const navigate = useNavigate();
  const { deleteBuild } = useSavedBuilds();
  const total = build.products.reduce((sum, p) => sum + p.price, 0);

  const handleLoad = () => {
    navigate('/', { state: { loadBuild: build } });
  };

  const handleShare = async () => {
    const hash = encodeBuild(build.products);
    const url = `${window.location.origin}/build/${hash}`;
    await navigator.clipboard.writeText(url);
  };

  return (
    <div className="bg-white rounded-lg shadow-md p-6">
      <div className="flex justify-between items-start">
        <div>
          <h3 className="text-lg font-semibold text-gray-900">{build.name}</h3>
          <p className="text-sm text-gray-500 mt-1">
            Last updated: {new Date(build.updatedAt).toLocaleDateString()}
          </p>
        </div>
        <div className="flex items-center gap-2">
          <button
            onClick={handleShare}
            className="p-2 text-gray-600 hover:text-gray-900 rounded-full hover:bg-gray-100"
            title="Share build"
          >
            <Share2 className="h-5 w-5" />
          </button>
          <button
            onClick={handleLoad}
            className="p-2 text-blue-600 hover:text-blue-700 rounded-full hover:bg-blue-50"
            title="Edit build"
          >
            <Edit2 className="h-5 w-5" />
          </button>
          <button
            onClick={() => deleteBuild(build.id)}
            className="p-2 text-red-600 hover:text-red-700 rounded-full hover:bg-red-50"
            title="Delete build"
          >
            <Trash2 className="h-5 w-5" />
          </button>
        </div>
      </div>

      <div className="mt-4">
        <div className="flex flex-wrap gap-2">
          {build.products.map(product => (
            <div
              key={product.id}
              className="bg-gray-100 px-3 py-1 rounded-full text-sm text-gray-700"
            >
              {product.name}
            </div>
          ))}
        </div>
      </div>

      <div className="mt-4 pt-4 border-t flex justify-between items-center">
        <span className="text-gray-600">Total:</span>
        <span className="text-lg font-semibold text-gray-900">
          ${total.toLocaleString()}
        </span>
      </div>
    </div>
  );
}