import React from 'react';
import { useSavedBuilds } from '../../hooks/useSavedBuilds';
import { SavedBuildCard } from './SavedBuildCard';
import { EmptyState } from '../EmptyState';

export function SavedBuildsList() {
  const { savedBuilds, isLoading } = useSavedBuilds();

  if (isLoading) {
    return (
      <div className="space-y-4">
        {[1, 2, 3].map(i => (
          <div key={i} className="animate-pulse bg-gray-100 h-32 rounded-lg" />
        ))}
      </div>
    );
  }

  if (savedBuilds.length === 0) {
    return (
      <EmptyState
        title="No saved builds"
        description="Start building your first system configuration"
        action={{
          label: "Create Build",
          href: "/"
        }}
      />
    );
  }

  return (
    <div className="space-y-4">
      {savedBuilds.map(build => (
        <SavedBuildCard key={build.id} build={build} />
      ))}
    </div>
  );
}