import React from 'react';
import { ForumReply } from '../../types/forum';
import { formatDate } from '../../utils/date';

interface ReplyListProps {
  replies: ForumReply[];
}

export function ReplyList({ replies }: ReplyListProps) {
  if (replies.length === 0) {
    return (
      <div className="p-6 text-center text-gray-500">
        No replies yet. Be the first to reply!
      </div>
    );
  }

  return (
    <div className="divide-y">
      {replies.map(reply => (
        <div key={reply.id} className="p-6">
          <div className="flex items-center gap-4 mb-4">
            <div className="flex-1">
              <div className="text-sm">
                <span className="font-medium text-gray-900">
                  {reply.author.username}
                </span>
                <span className="text-gray-500 ml-2">
                  replied {formatDate(reply.createdAt)}
                </span>
              </div>
            </div>
          </div>
          <div className="prose max-w-none">
            {reply.content}
          </div>
        </div>
      ))}
    </div>
  );
}