import React from 'react';
import { Link } from 'react-router-dom';
import { MessageSquare, Eye } from 'lucide-react';
import { ForumThread } from '../../types/forum';
import { formatDistanceToNow } from '../../utils/date';

interface ThreadListItemProps {
  thread: ForumThread;
}

export function ThreadListItem({ thread }: ThreadListItemProps) {
  return (
    <div className="p-6 hover:bg-gray-50">
      <div className="flex justify-between">
        <div className="flex-1">
          <Link 
            to={`/forum/thread/${thread.id}`}
            className="text-lg font-medium text-gray-900 hover:text-blue-600"
          >
            {thread.title}
          </Link>
          <div className="mt-1 text-sm text-gray-500">
            Started by {thread.author.username} • {formatDistanceToNow(thread.createdAt)}
          </div>
          <div className="mt-2 flex gap-2">
            {thread.tags.map(tag => (
              <span
                key={tag}
                className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-blue-100 text-blue-800"
              >
                {tag}
              </span>
            ))}
          </div>
        </div>

        <div className="ml-6 flex items-center gap-6">
          <div className="flex items-center gap-2 text-gray-500">
            <MessageSquare className="h-4 w-4" />
            <span className="text-sm">{thread.replies}</span>
          </div>
          <div className="flex items-center gap-2 text-gray-500">
            <Eye className="h-4 w-4" />
            <span className="text-sm">{thread.views}</span>
          </div>
        </div>
      </div>

      {thread.lastReply && (
        <div className="mt-4 text-sm text-gray-500">
          Last reply by {thread.lastReply.author.username} • {formatDistanceToNow(thread.lastReply.createdAt)}
        </div>
      )}
    </div>
  );
}