import React, { useState, useEffect } from 'react';
import { useAuth } from '../../hooks/useAuth';
import { useForumStore } from '../../stores/forumStore';
import { useNotificationStore } from '../../stores/notificationStore';

export function InboxProvider({ children }: { children: React.ReactNode }) {
  const { user } = useAuth();
  const { threads, replies } = useForumStore();
  const { addNotification } = useNotificationStore();
  const [processedReplies, setProcessedReplies] = useState<Set<string>>(new Set());

  useEffect(() => {
    if (!user) return;

    // Check for new replies to user's threads
    threads.forEach(thread => {
      if (thread.author.id === user.id) {
        const threadReplies = replies[thread.id] || [];
        threadReplies.forEach(reply => {
          if (
            reply.author.id !== user.id && 
            !processedReplies.has(reply.id)
          ) {
            addNotification({
              userId: user.id,
              threadId: thread.id,
              replyId: reply.id,
              title: thread.title,
              content: reply.content,
              author: {
                username: reply.author.username,
                avatar: reply.author.avatar
              }
            });
            setProcessedReplies(prev => new Set([...prev, reply.id]));
          }
        });
      }
    });
  }, [user, threads, replies, addNotification]);

  return <>{children}</>;
}