import React from 'react';
import { Link, useLocation } from 'react-router-dom';
import { Scale, LineChart, MessageSquare, Users, Wrench, Package } from 'lucide-react';
import { useAuth } from '../../hooks/useAuth';
import { useCompare } from '../../hooks/useCompare';
import { ProductsMenu } from './ProductsMenu';

export function MainNav() {
  const { isAuthenticated } = useAuth();
  const { products } = useCompare();
  const location = useLocation();

  return (
    <nav className="bg-white shadow-md">
      <div className="max-w-7xl mx-auto px-4">
        <div className="flex justify-between items-center h-16">
          <Link to="/" className="text-xl font-bold text-gray-800">
            GolfSimPicker
          </Link>
          
          <div className="flex items-center space-x-4">
            <Link
              to="/"
              className={`flex items-center gap-2 px-3 py-2 rounded-md ${
                location.pathname === '/'
                  ? 'text-blue-600 bg-blue-50'
                  : 'text-gray-600 hover:text-gray-900 hover:bg-gray-50'
              }`}
            >
              <Wrench className="h-5 w-5" />
              <span className="text-sm font-medium">Builder</span>
            </Link>
            <ProductsMenu />
            <Link
              to="/community"
              className={`flex items-center gap-2 px-3 py-2 rounded-md ${
                location.pathname.startsWith('/community')
                  ? 'text-blue-600 bg-blue-50'
                  : 'text-gray-600 hover:text-gray-900 hover:bg-gray-50'
              }`}
            >
              <Users className="h-5 w-5" />
              <span className="text-sm font-medium">Community</span>
            </Link>
            <Link
              to="/forum"
              className={`flex items-center gap-2 px-3 py-2 rounded-md ${
                location.pathname.startsWith('/forum')
                  ? 'text-blue-600 bg-blue-50'
                  : 'text-gray-600 hover:text-gray-900 hover:bg-gray-50'
              }`}
            >
              <MessageSquare className="h-5 w-5" />
              <span className="text-sm font-medium">Forum</span>
            </Link>
            <Link
              to="/trends"
              className={`flex items-center gap-2 px-3 py-2 rounded-md ${
                location.pathname === '/trends'
                  ? 'text-blue-600 bg-blue-50'
                  : 'text-gray-600 hover:text-gray-900 hover:bg-gray-50'
              }`}
            >
              <LineChart className="h-5 w-5" />
              <span className="text-sm font-medium">Trends</span>
            </Link>
            <Link
              to="/compare"
              className={`flex items-center gap-2 px-3 py-2 rounded-md ${
                location.pathname === '/compare'
                  ? 'text-blue-600 bg-blue-50'
                  : 'text-gray-600 hover:text-gray-900 hover:bg-gray-50'
              }`}
            >
              <Scale className="h-5 w-5" />
              <span className="text-sm font-medium">Compare</span>
              {products.length > 0 && (
                <span className="bg-blue-600 text-white text-xs rounded-full h-5 w-5 flex items-center justify-center">
                  {products.length}
                </span>
              )}
            </Link>

            {!isAuthenticated && (
              <>
                <Link
                  to="/login"
                  className="px-4 py-2 text-gray-700 hover:text-gray-900"
                >
                  Sign In
                </Link>
                <Link
                  to="/register"
                  className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
                >
                  Register
                </Link>
              </>
            )}
          </div>
        </div>
      </div>
    </nav>
  );
}