import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import { 
  Package, 
  ChevronDown,
  Camera, 
  Projector,
  Box,
  Monitor,
  Square,
  Laptop,
  Wrench
} from 'lucide-react';
import { categories } from '../../data/categories';

const categoryIcons = {
  launch_monitor: Camera,
  projector: Projector,
  enclosure: Box,
  impact_screen: Monitor,
  hitting_mat: Square,
  computer: Laptop
} as const;

export function ProductsMenu() {
  const [isOpen, setIsOpen] = useState(false);

  return (
    <div className="relative">
      <button
        onClick={() => setIsOpen(!isOpen)}
        className="flex items-center gap-2 px-3 py-2 text-gray-600 hover:text-gray-900 hover:bg-gray-50 rounded-md"
      >
        <Package className="h-5 w-5" />
        <span className="text-sm font-medium">Products</span>
        <ChevronDown className={`h-4 w-4 transition-transform ${isOpen ? 'rotate-180' : ''}`} />
      </button>

      {isOpen && (
        <>
          <div 
            className="fixed inset-0 z-40"
            onClick={() => setIsOpen(false)}
          />
          <div className="absolute left-0 mt-2 w-[600px] bg-white rounded-lg shadow-lg border border-gray-200 z-50">
            <div className="grid grid-cols-3 gap-2 p-3">
              {categories.map(({ label, value }) => {
                const Icon = categoryIcons[value];
                return (
                  <Link
                    key={value}
                    to={`/category/${value}`}
                    className="flex items-center gap-3 p-3 rounded-md hover:bg-gray-50"
                    onClick={() => setIsOpen(false)}
                  >
                    <Icon className="h-5 w-5 text-blue-600" />
                    <span className="text-sm font-medium text-gray-900">{label}</span>
                  </Link>
                );
              })}
              <Link
                to="/accessories"
                className="flex items-center gap-3 p-3 rounded-md hover:bg-gray-50"
                onClick={() => setIsOpen(false)}
              >
                <Wrench className="h-5 w-5 text-blue-600" />
                <span className="text-sm font-medium text-gray-900">Accessories</span>
              </Link>
            </div>
          </div>
        </>
      )}
    </div>
  );
}