import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import { Heart, User, LogOut, Bookmark } from 'lucide-react';
import { useAuth } from '../../hooks/useAuth';
import { useFavorites } from '../../hooks/useFavorites';
import { useSavedBuilds } from '../../hooks/useSavedBuilds';
import { InboxButton } from '../inbox/InboxButton';
import { InboxDropdown } from '../inbox/InboxDropdown';

export function TopNav() {
  const { isAuthenticated, logout } = useAuth();
  const { favorites } = useFavorites();
  const { savedBuilds } = useSavedBuilds();
  const [isInboxOpen, setIsInboxOpen] = useState(false);

  if (!isAuthenticated) return null;

  return (
    <div className="bg-gray-50 border-b border-gray-200">
      <div className="max-w-7xl mx-auto px-4">
        <div className="flex justify-end items-center h-10">
          <div className="flex items-center space-x-4">
            <Link
              to="/favorites"
              className="flex items-center gap-1 text-sm text-gray-600 hover:text-gray-900"
            >
              <Heart className="h-4 w-4" />
              <span>Favorites</span>
              {favorites.length > 0 && (
                <span className="bg-blue-600 text-white text-xs rounded-full h-4 w-4 flex items-center justify-center">
                  {favorites.length}
                </span>
              )}
            </Link>
            <Link
              to="/saved-builds"
              className="flex items-center gap-1 text-sm text-gray-600 hover:text-gray-900"
            >
              <Bookmark className="h-4 w-4" />
              <span>Saved Builds</span>
              {savedBuilds.length > 0 && (
                <span className="bg-blue-600 text-white text-xs rounded-full h-4 w-4 flex items-center justify-center">
                  {savedBuilds.length}
                </span>
              )}
            </Link>
            <Link
              to="/dashboard"
              className="flex items-center gap-1 text-sm text-gray-600 hover:text-gray-900"
            >
              <User className="h-4 w-4" />
              <span>Dashboard</span>
            </Link>
            <div className="relative">
              <InboxButton onClick={() => setIsInboxOpen(!isInboxOpen)} />
              {isInboxOpen && (
                <>
                  <div
                    className="fixed inset-0 z-40"
                    onClick={() => setIsInboxOpen(false)}
                  />
                  <InboxDropdown onClose={() => setIsInboxOpen(false)} />
                </>
              )}
            </div>
            <button
              onClick={logout}
              className="flex items-center gap-1 text-sm text-gray-600 hover:text-gray-900"
            >
              <LogOut className="h-4 w-4" />
              <span>Sign Out</span>
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}