import React, { useState } from 'react';
import { Bell } from 'lucide-react';
import { Product } from '../../types';
import { useAuth } from '../../hooks/useAuth';
import { usePriceAlertStore } from '../../stores/priceAlertStore';
import { AuthModal } from '../auth/AuthModal';

interface PriceAlertButtonProps {
  product: Product;
}

export function PriceAlertButton({ product }: PriceAlertButtonProps) {
  const { isAuthenticated } = useAuth();
  const [showAuthModal, setShowAuthModal] = useState(false);

  const handleClick = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    
    if (!isAuthenticated) {
      setShowAuthModal(true);
      return;
    }
  };

  return (
    <>
      <button
        onClick={handleClick}
        className="flex items-center gap-2 px-4 py-2 text-gray-700 hover:text-gray-900 border border-gray-300 rounded-md hover:bg-gray-50"
      >
        <Bell className="h-4 w-4" />
        <span>Set Price Alert</span>
      </button>

      <AuthModal 
        isOpen={showAuthModal} 
        onClose={() => setShowAuthModal(false)} 
      />
    </>
  );
}