import React from 'react';
import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  Title,
  Tooltip,
  Legend,
  TimeScale
} from 'chart.js';
import { Line } from 'react-chartjs-2';
import { usePriceTrends } from '../../hooks/usePriceTrends';
import { ProductCategory } from '../../types';

ChartJS.register(
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  Title,
  Tooltip,
  Legend,
  TimeScale
);

interface PriceTrendsChartProps {
  category: ProductCategory;
  timeRange: '1M' | '3M' | '6M' | '1Y';
}

export function PriceTrendsChart({ category, timeRange }: PriceTrendsChartProps) {
  const { data, isLoading } = usePriceTrends(category, timeRange);

  if (isLoading) {
    return (
      <div className="h-96 flex items-center justify-center">
        <p className="text-gray-500">Loading price trends...</p>
      </div>
    );
  }

  const options = {
    responsive: true,
    maintainAspectRatio: false,
    interaction: {
      mode: 'index' as const,
      intersect: false,
    },
    plugins: {
      legend: {
        position: 'bottom' as const,
      },
      tooltip: {
        callbacks: {
          label: (context: any) => `$${context.parsed.y.toLocaleString()}`
        }
      }
    },
    scales: {
      x: {
        grid: {
          display: false
        }
      },
      y: {
        beginAtZero: false,
        ticks: {
          callback: (value: number) => `$${value.toLocaleString()}`
        }
      }
    }
  };

  return (
    <div className="h-96">
      <Line data={data} options={options} />
    </div>
  );
}