import React from 'react';
import { ProductCategory } from '../../types';
import { categories } from '../../data/categories';

interface PriceTrendsFiltersProps {
  selectedCategory: ProductCategory;
  onCategoryChange: (category: ProductCategory) => void;
  timeRange: '1M' | '3M' | '6M' | '1Y';
  onTimeRangeChange: (range: '1M' | '3M' | '6M' | '1Y') => void;
}

export function PriceTrendsFilters({
  selectedCategory,
  onCategoryChange,
  timeRange,
  onTimeRangeChange
}: PriceTrendsFiltersProps) {
  const timeRanges = [
    { value: '1M', label: '1 Month' },
    { value: '3M', label: '3 Months' },
    { value: '6M', label: '6 Months' },
    { value: '1Y', label: '1 Year' }
  ] as const;

  return (
    <div className="space-y-6">
      <div className="bg-white p-4 rounded-lg shadow-md">
        <h3 className="text-lg font-semibold mb-4">Categories</h3>
        <div className="space-y-2">
          {categories.map(({ label, value }) => (
            <button
              key={value}
              onClick={() => onCategoryChange(value)}
              className={`w-full text-left px-3 py-2 rounded-md transition-colors ${
                selectedCategory === value
                  ? 'bg-blue-100 text-blue-700'
                  : 'hover:bg-gray-100'
              }`}
            >
              {label}
            </button>
          ))}
        </div>
      </div>

      <div className="bg-white p-4 rounded-lg shadow-md">
        <h3 className="text-lg font-semibold mb-4">Time Range</h3>
        <div className="space-y-2">
          {timeRanges.map(({ value, label }) => (
            <button
              key={value}
              onClick={() => onTimeRangeChange(value)}
              className={`w-full text-left px-3 py-2 rounded-md transition-colors ${
                timeRange === value
                  ? 'bg-blue-100 text-blue-700'
                  : 'hover:bg-gray-100'
              }`}
            >
              {label}
            </button>
          ))}
        </div>
      </div>
    </div>
  );
}