import { useState } from 'react';
import { Product } from '../types';

interface HistoryEntry {
  product: Product;
  timestamp: string;
  action: 'added' | 'removed';
}

export function useBuildHistory() {
  const [history, setHistory] = useState<HistoryEntry[]>([]);

  const addToHistory = (product: Product, action: 'added' | 'removed') => {
    setHistory(prev => [{
      product,
      action,
      timestamp: new Date().toISOString()
    }, ...prev]);
  };

  const clearHistory = () => {
    setHistory([]);
  };

  return {
    history,
    addToHistory,
    clearHistory
  };
}