import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { Product } from '../types';

interface CompareStore {
  products: Product[];
  toggleCompare: (product: Product) => string | null;
  isInComparison: (productId: string) => boolean;
  clearComparison: () => void;
  removeProduct: (productId: string) => void;
}

export const useCompare = create<CompareStore>()(
  persist(
    (set, get) => ({
      products: [],
      toggleCompare: (product) => {
        const { products } = get();
        const isAlreadyAdded = products.some(p => p.id === product.id);
        
        if (isAlreadyAdded) {
          set({ products: products.filter(p => p.id !== product.id) });
          return null;
        }

        if (products.length > 0 && products[0].category !== product.category) {
          return 'You can only compare products from the same category';
        }

        if (products.length >= 4) {
          return 'You can compare up to 4 products at a time';
        }

        set({ products: [...products, product] });
        return null;
      },
      isInComparison: (productId) => {
        return get().products.some(p => p.id === productId);
      },
      clearComparison: () => set({ products: [] }),
      removeProduct: (productId) => {
        const { products } = get();
        set({ products: products.filter(p => p.id !== productId) });
      }
    }),
    {
      name: 'product-comparison'
    }
  )
);