import { useState, useEffect } from 'react';
import { useAuth } from './useAuth';
import { Product } from '../types';

export function useFavorites() {
  const { user } = useAuth();
  const [favorites, setFavorites] = useState<Product[]>([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    if (!user) {
      setFavorites([]);
      setIsLoading(false);
      return;
    }

    const loadFavorites = () => {
      try {
        const storedFavorites = localStorage.getItem(`favorites_${user.id}`);
        if (storedFavorites) {
          setFavorites(JSON.parse(storedFavorites));
        }
      } catch (error) {
        console.error('Failed to load favorites:', error);
      } finally {
        setIsLoading(false);
      }
    };

    loadFavorites();
  }, [user]);

  const toggleFavorite = (product: Product) => {
    if (!user) return;

    try {
      const newFavorites = favorites.some(f => f.id === product.id)
        ? favorites.filter(f => f.id !== product.id)
        : [...favorites, product];

      localStorage.setItem(`favorites_${user.id}`, JSON.stringify(newFavorites));
      setFavorites(newFavorites);
    } catch (error) {
      console.error('Failed to update favorite:', error);
    }
  };

  const isFavorite = (productId: string) => {
    return favorites.some(f => f.id === productId);
  };

  return {
    favorites,
    isLoading,
    toggleFavorite,
    isFavorite
  };
}