import { useState, useMemo } from 'react';
import { Product } from '../types';

export function useFilters(products: Product[]) {
  const [minPrice, setMinPrice] = useState(0);
  const [maxPrice, setMaxPrice] = useState(Infinity);
  const [selectedBrands, setSelectedBrands] = useState<string[]>([]);

  const brands = useMemo(() => {
    const brandSet = new Set(products.map(product => product.brand));
    return Array.from(brandSet).sort();
  }, [products]);

  const filteredProducts = useMemo(() => {
    return products.filter(product => {
      const matchesPrice = product.price >= minPrice && product.price <= maxPrice;
      const matchesBrand = selectedBrands.length === 0 || selectedBrands.includes(product.brand);
      return matchesPrice && matchesBrand;
    });
  }, [products, minPrice, maxPrice, selectedBrands]);

  return {
    minPrice,
    maxPrice,
    setMinPrice,
    setMaxPrice,
    brands,
    selectedBrands,
    setSelectedBrands,
    filteredProducts
  };
}