import { useState, useEffect } from 'react';
import { Product } from '../types';
import { products } from '../data/products';

export function useProduct(productId: string | undefined) {
  const [product, setProduct] = useState<Product | null>(null);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<Error | null>(null);

  useEffect(() => {
    if (!productId) {
      setError(new Error('Product ID is required'));
      setIsLoading(false);
      return;
    }

    const foundProduct = products.find(p => p.id === productId);
    if (foundProduct) {
      setProduct(foundProduct);
    } else {
      setError(new Error('Product not found'));
    }
    setIsLoading(false);
  }, [productId]);

  return { product, isLoading, error };
}