import React, { useState } from 'react';
import { AccessoryGrid } from '../components/accessories/AccessoryGrid';
import { AccessoryTypeFilter } from '../components/accessories/AccessoryTypeFilter';
import { accessories } from '../data/accessories';
import { AccessoryType } from '../types/accessory';
import { SearchBar } from '../components/SearchBar';

export function AccessoriesPage() {
  const [selectedType, setSelectedType] = useState<AccessoryType | null>(null);
  const [searchQuery, setSearchQuery] = useState('');

  const filteredAccessories = React.useMemo(() => {
    let filtered = selectedType
      ? accessories.filter(acc => acc.type === selectedType)
      : accessories;

    if (searchQuery) {
      const query = searchQuery.toLowerCase();
      filtered = filtered.filter(acc =>
        acc.name.toLowerCase().includes(query) ||
        acc.brand.toLowerCase().includes(query) ||
        acc.description.toLowerCase().includes(query)
      );
    }

    return filtered;
  }, [selectedType, searchQuery]);

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-gray-900">Simulator Accessories</h1>
        <p className="text-gray-600 mt-1">
          Essential add-ons to enhance your simulator setup
        </p>
      </div>

      <div className="grid grid-cols-12 gap-8">
        <div className="col-span-3">
          <AccessoryTypeFilter
            selectedType={selectedType}
            onChange={setSelectedType}
          />
        </div>
        <div className="col-span-9">
          <div className="mb-6">
            <SearchBar 
              value={searchQuery}
              onChange={setSearchQuery}
              placeholder="Search accessories..."
            />
          </div>
          <AccessoryGrid accessories={filteredAccessories} />
        </div>
      </div>
    </main>
  );
}