import React, { useEffect } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';
import { BuildList } from '../components/BuildList/BuildList';
import { BuildListActions } from '../components/BuildList/BuildListActions';
import { Product } from '../types';
import { SavedBuild } from '../hooks/useSavedBuilds';
import { useBuildHistory } from '../hooks/useBuildHistory';

interface BuilderPageProps {
  selectedProducts: Product[];
  setSelectedProducts: (products: Product[]) => void;
}

interface LocationState {
  loadBuild?: SavedBuild;
}

export function BuilderPage({ selectedProducts, setSelectedProducts }: BuilderPageProps) {
  const navigate = useNavigate();
  const location = useLocation();
  const state = location.state as LocationState;
  const { addToHistory } = useBuildHistory();

  // Load saved build if provided in navigation state
  useEffect(() => {
    if (state?.loadBuild) {
      setSelectedProducts(state.loadBuild.products);
      state.loadBuild.products.forEach(product => {
        addToHistory(product, 'added');
      });
      navigate('/', { replace: true });
    }
  }, [state, setSelectedProducts, navigate, addToHistory]);

  const handleRemoveProduct = (product: Product) => {
    setSelectedProducts(selectedProducts.filter(p => p.id !== product.id));
    addToHistory(product, 'removed');
  };

  const handleSelectCategory = (category: string) => {
    navigate(`/category/${category}`);
  };

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="space-y-6">
        <div className="flex justify-between items-center">
          <h1 className="text-2xl font-bold text-gray-900">System Builder</h1>
          <BuildListActions selectedProducts={selectedProducts} />
        </div>
        <BuildList
          selectedProducts={selectedProducts}
          onRemove={handleRemoveProduct}
          onSelectCategory={handleSelectCategory}
        />
      </div>
    </main>
  );
}