import React from 'react';
import { useParams, Link } from 'react-router-dom';
import { ChevronLeft, Heart, MessageSquare } from 'lucide-react';
import { useCommunityBuild } from '../hooks/useCommunityBuild';
import { BuildList } from '../components/BuildList/BuildList';

export function CommunityBuildDetailsPage() {
  const { buildId } = useParams<{ buildId: string }>();
  const { build, isLoading } = useCommunityBuild(buildId);

  if (isLoading) {
    return (
      <main className="max-w-7xl mx-auto px-4 py-8">
        <div className="animate-pulse space-y-4">
          <div className="h-8 bg-gray-200 rounded w-1/4" />
          <div className="h-64 bg-gray-200 rounded-lg" />
        </div>
      </main>
    );
  }

  if (!build) {
    return (
      <main className="max-w-7xl mx-auto px-4 py-8">
        <p>Build not found</p>
      </main>
    );
  }

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="mb-8">
        <Link
          to="/community"
          className="inline-flex items-center text-gray-600 hover:text-gray-900"
        >
          <ChevronLeft className="h-5 w-5" />
          <span>Back to Community Builds</span>
        </Link>
      </div>

      <div className="bg-white rounded-lg shadow-md p-6 mb-8">
        <div className="flex justify-between items-start mb-6">
          <div>
            <h1 className="text-2xl font-bold text-gray-900">{build.title}</h1>
            <p className="text-gray-600">by {build.author.username}</p>
          </div>
          <div className="flex items-center gap-4 text-gray-500">
            <button className="flex items-center gap-1 hover:text-gray-900">
              <Heart className="h-5 w-5" />
              <span>{build.likes}</span>
            </button>
            <button className="flex items-center gap-1 hover:text-gray-900">
              <MessageSquare className="h-5 w-5" />
              <span>{build.comments}</span>
            </button>
          </div>
        </div>

        <p className="text-gray-700 mb-6">{build.description}</p>

        <div className="flex flex-wrap gap-2 mb-6">
          {build.tags.map(tag => (
            <span
              key={tag}
              className="px-3 py-1 bg-blue-100 text-blue-800 rounded-full text-sm font-medium"
            >
              {tag}
            </span>
          ))}
        </div>

        <BuildList
          selectedProducts={build.products}
          onRemove={() => {}}
          onSelectCategory={() => {}}
        />
      </div>
    </main>
  );
}