import React from 'react';
import { useNavigate } from 'react-router-dom';
import { ChevronLeft } from 'lucide-react';
import { useCompare } from '../hooks/useCompare';
import { CompareTable } from '../components/compare/CompareTable';
import { EmptyState } from '../components/EmptyState';
import { CompareHeader } from '../components/compare/CompareHeader';

export function ComparePage() {
  const navigate = useNavigate();
  const { products } = useCompare();

  if (products.length === 0) {
    return (
      <main className="max-w-7xl mx-auto px-4 py-8">
        <EmptyState
          title="No products to compare"
          description="Add products to your comparison list to see them here"
          action={{
            label: "Browse Products",
            href: "/category/launch_monitor"
          }}
        />
      </main>
    );
  }

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="flex items-center gap-4 mb-8">
        <button
          onClick={() => navigate(-1)}
          className="flex items-center gap-2 text-gray-600 hover:text-gray-900"
        >
          <ChevronLeft className="h-5 w-5" />
          Back
        </button>
        <h1 className="text-2xl font-bold text-gray-900">Compare Products</h1>
      </div>

      <CompareHeader />
      <CompareTable products={products} />
    </main>
  );
}