import React from 'react';
import { useFavorites } from '../hooks/useFavorites';
import { EmptyState } from '../components/EmptyState';
import { RequireAuth } from '../components/auth/RequireAuth';
import { ProductCard } from '../components/ProductCard';
import { useNavigate } from 'react-router-dom';
import { Product } from '../types';

interface FavoritesPageProps {
  selectedProducts: Product[];
  setSelectedProducts: (products: Product[]) => void;
}

export function FavoritesPage({ selectedProducts, setSelectedProducts }: FavoritesPageProps) {
  const { favorites, isLoading } = useFavorites();
  const navigate = useNavigate();

  const handleSelect = (product: Product) => {
    setSelectedProducts(prev => {
      const filtered = prev.filter(p => p.category !== product.category);
      return [...filtered, product];
    });
    navigate('/');
  };

  if (isLoading) {
    return (
      <main className="max-w-7xl mx-auto px-4 py-8">
        <div className="animate-pulse space-y-4">
          <div className="h-8 bg-gray-200 rounded w-1/4"></div>
          <div className="grid grid-cols-1 gap-6">
            {[1, 2, 3].map(i => (
              <div key={i} className="h-48 bg-gray-200 rounded-lg"></div>
            ))}
          </div>
        </div>
      </main>
    );
  }

  return (
    <RequireAuth>
      <main className="max-w-7xl mx-auto px-4 py-8">
        <h1 className="text-2xl font-bold text-gray-900 mb-8">Favorite Parts</h1>
        
        {favorites.length > 0 ? (
          <div className="grid grid-cols-1 gap-4">
            {favorites.map(product => (
              <ProductCard
                key={product.id}
                product={product}
                onSelect={handleSelect}
                showCompare={false}
              />
            ))}
          </div>
        ) : (
          <EmptyState
            title="No favorites yet"
            description="Start adding products to your favorites to see them here."
            action={{
              label: "Browse Products",
              href: "/category/launch_monitor"
            }}
          />
        )}
      </main>
    </RequireAuth>
  );
}