import React, { useState } from 'react';
import { PriceTrendsChart } from '../components/trends/PriceTrendsChart';
import { PriceTrendsFilters } from '../components/trends/PriceTrendsFilters';
import { ProductCategory } from '../types';
import { categories } from '../data/categories';

export function PriceTrendsPage() {
  const [selectedCategory, setSelectedCategory] = useState<ProductCategory>('launch_monitor');
  const [timeRange, setTimeRange] = useState<'1M' | '3M' | '6M' | '1Y'>('3M');

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-gray-900">Price Trends</h1>
        <p className="text-gray-600 mt-1">
          Track price changes across different product categories
        </p>
      </div>

      <div className="grid grid-cols-12 gap-8">
        <div className="col-span-3">
          <PriceTrendsFilters
            selectedCategory={selectedCategory}
            onCategoryChange={setSelectedCategory}
            timeRange={timeRange}
            onTimeRangeChange={setTimeRange}
          />
        </div>

        <div className="col-span-9">
          <div className="bg-white rounded-lg shadow-md p-6">
            <PriceTrendsChart
              category={selectedCategory}
              timeRange={timeRange}
            />
          </div>
        </div>
      </div>
    </main>
  );
}