import React from 'react';
import { useParams, Link } from 'react-router-dom';
import { ChevronLeft } from 'lucide-react';
import { useProduct } from '../hooks/useProduct';
import { ProductSpecs } from '../components/product/ProductSpecs';
import { ProductHeader } from '../components/product/ProductHeader';
import { PriceHistory } from '../components/product/PriceHistory';
import { AddToBuildButton } from '../components/product/AddToBuildButton';

export function ProductDetailsPage() {
  const { productId } = useParams<{ productId: string }>();
  const { product, isLoading, error } = useProduct(productId);

  if (isLoading) {
    return <div className="max-w-7xl mx-auto px-4 py-8">Loading...</div>;
  }

  if (error || !product) {
    return <div className="max-w-7xl mx-auto px-4 py-8">Product not found</div>;
  }

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="mb-8">
        <Link
          to={`/category/${product.category}`}
          className="inline-flex items-center text-gray-600 hover:text-gray-900"
        >
          <ChevronLeft className="h-5 w-5" />
          <span>Back to {product.category.replace('_', ' ')}</span>
        </Link>
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-8">
        <div className="lg:col-span-2 space-y-8">
          <ProductHeader product={product} />
          <ProductSpecs product={product} />
        </div>

        <div className="space-y-6">
          <AddToBuildButton product={product} />
          <PriceHistory productId={product.id} />
        </div>
      </div>
    </main>
  );
}