import React, { useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { decodeBuild } from '../utils/buildShare';
import { products } from '../data/products';
import { Product } from '../types';

interface SharedBuildPageProps {
  setSelectedProducts: (products: Product[]) => void;
}

export function SharedBuildPage({ setSelectedProducts }: SharedBuildPageProps) {
  const { hash } = useParams<{ hash: string }>();
  const navigate = useNavigate();

  useEffect(() => {
    if (hash) {
      const productIds = decodeBuild(hash);
      const sharedProducts = products.filter(p => productIds.includes(p.id));
      setSelectedProducts(sharedProducts);
      navigate('/');
    }
  }, [hash, setSelectedProducts, navigate]);

  return null;
}