import React, { createContext, useState, useEffect } from 'react';
import { AuthContext } from '../hooks/useAuth';

interface User {
  id: string;
  email: string;
  username: string;
}

interface AuthProviderProps {
  children: React.ReactNode;
}

// Test account credentials
const TEST_ACCOUNT = {
  email: 'test@example.com',
  password: 'Test123!',
  userData: {
    id: '1',
    email: 'test@example.com',
    username: 'testuser'
  }
};

export function AuthProvider({ children }: AuthProviderProps) {
  const [user, setUser] = useState<User | null>(null);

  useEffect(() => {
    // Check for existing session
    const storedUser = localStorage.getItem('user');
    if (storedUser) {
      setUser(JSON.parse(storedUser));
    }
  }, []);

  const login = async (email: string, password: string) => {
    try {
      await new Promise(resolve => setTimeout(resolve, 1000)); // Simulate API delay
      
      // Check if credentials match test account
      if (email === TEST_ACCOUNT.email && password === TEST_ACCOUNT.password) {
        localStorage.setItem('user', JSON.stringify(TEST_ACCOUNT.userData));
        setUser(TEST_ACCOUNT.userData);
        return;
      }
      
      throw new Error('Invalid credentials');
    } catch (error) {
      throw new Error('Invalid credentials');
    }
  };

  const logout = () => {
    localStorage.removeItem('user');
    setUser(null);
  };

  return (
    <AuthContext.Provider value={{
      user,
      isAuthenticated: !!user,
      login,
      logout
    }}>
      {children}
    </AuthContext.Provider>
  );
}