import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { CommunityBuild } from '../types/community';
import { products } from '../data/products';

interface CommunityStore {
  builds: CommunityBuild[];
  addBuild: (build: Omit<CommunityBuild, 'id'>) => void;
  likeBuild: (buildId: string) => void;
  addComment: (buildId: string) => void;
}

// Initial example builds with real products
const initialBuilds: CommunityBuild[] = [
  {
    id: '1',
    title: 'Ultimate Pro Setup',
    description: 'Professional-grade simulator setup with GC3, premium screen, and top-tier components',
    author: {
      id: '1',
      username: 'golfpro',
      email: '',
      joinedAt: '2024-01-01T00:00:00.000Z',
      postCount: 0
    },
    products: [
      products.find(p => p.id === 'lm1')!,  // GC3
      products.find(p => p.id === 'p2')!,   // BenQ Projector
      products.find(p => p.id === 'e2')!,   // Premium Enclosure
      products.find(p => p.id === 'is4')!,  // Elite Screen
      products.find(p => p.id === 'hm5')!,  // Commercial Mat
      products.find(p => p.id === 'c4')!    // Pro Workstation
    ],
    image: 'https://images.unsplash.com/photo-1592595896616-c37162298647?auto=format&fit=crop&q=80&w=2070',
    tags: ['Premium', 'Professional', 'Commercial'],
    likes: 156,
    comments: 42,
    createdAt: '2024-01-15T10:00:00.000Z',
    updatedAt: '2024-01-15T10:00:00.000Z'
  },
  {
    id: '2',
    title: 'Mid-Range Home Setup',
    description: 'Perfect balance of performance and value for serious home golfers',
    author: {
      id: '2',
      username: 'golfenthusiast',
      email: '',
      joinedAt: '2024-01-01T00:00:00.000Z',
      postCount: 0
    },
    products: [
      products.find(p => p.id === 'lm2')!,  // SkyTrak+
      products.find(p => p.id === 'p1')!,   // Optoma Projector
      products.find(p => p.id === 'e1')!,   // Pro Enclosure
      products.find(p => p.id === 'is1')!,  // Premium Screen
      products.find(p => p.id === 'hm2')!,  // Premium Mat
      products.find(p => p.id === 'c3')!    // Basic Gaming PC
    ],
    image: 'https://images.unsplash.com/photo-1535131749006-b7f58c99034b?auto=format&fit=crop&q=80&w=2070',
    tags: ['Mid-Range', 'Home', 'Value'],
    likes: 89,
    comments: 23,
    createdAt: '2024-01-16T10:00:00.000Z',
    updatedAt: '2024-01-16T10:00:00.000Z'
  },
  {
    id: '3',
    title: 'Budget-Friendly Garage Build',
    description: 'Affordable garage setup without compromising on core features',
    author: {
      id: '3',
      username: 'golfbeginner',
      email: '',
      joinedAt: '2024-01-01T00:00:00.000Z',
      postCount: 0
    },
    products: [
      products.find(p => p.id === 'lm3')!,  // Mevo+
      products.find(p => p.id === 'p1')!,   // Optoma Projector
      products.find(p => p.id === 'e5')!,   // DIY Kit
      products.find(p => p.id === 'is5')!,  // Basic Screen
      products.find(p => p.id === 'hm4')!,  // Basic Mat
      products.find(p => p.id === 'c3')!    // Basic Gaming PC
    ],
    image: 'https://images.unsplash.com/photo-1505373877841-8d25f7d46678?auto=format&fit=crop&q=80&w=2070',
    tags: ['Budget', 'Garage', 'DIY'],
    likes: 212,
    comments: 67,
    createdAt: '2024-01-17T10:00:00.000Z',
    updatedAt: '2024-01-17T10:00:00.000Z'
  },
  {
    id: '4',
    title: 'Compact Studio Setup',
    description: 'Space-efficient setup perfect for apartments or small rooms',
    author: {
      id: '4',
      username: 'citygolfer',
      email: '',
      joinedAt: '2024-01-01T00:00:00.000Z',
      postCount: 0
    },
    products: [
      products.find(p => p.id === 'lm2')!,  // SkyTrak+
      products.find(p => p.id === 'p1')!,   // Optoma Short Throw
      products.find(p => p.id === 'e3')!,   // Compact Enclosure
      products.find(p => p.id === 'is3')!,  // Performance Screen
      products.find(p => p.id === 'hm2')!,  // Premium Mat
      products.find(p => p.id === 'c5')!    // Compact Gaming PC
    ],
    image: 'https://images.unsplash.com/photo-1592595896616-c37162298647?auto=format&fit=crop&q=80&w=2070',
    tags: ['Compact', 'Studio', 'Space-Saving'],
    likes: 145,
    comments: 38,
    createdAt: '2024-01-18T10:00:00.000Z',
    updatedAt: '2024-01-18T10:00:00.000Z'
  },
  {
    id: '5',
    title: 'Premium Home Entertainment',
    description: 'High-end home setup optimized for both golf and entertainment',
    author: {
      id: '5',
      username: 'luxurygolfer',
      email: '',
      joinedAt: '2024-01-01T00:00:00.000Z',
      postCount: 0
    },
    products: [
      products.find(p => p.id === 'lm4')!,  // Uneekor QED
      products.find(p => p.id === 'p2')!,   // BenQ 4K
      products.find(p => p.id === 'e2')!,   // Premium Retractable
      products.find(p => p.id === 'is2')!,  // Pro Series Screen
      products.find(p => p.id === 'hm3')!,  // Tour Links Mat
      products.find(p => p.id === 'c2')!    // Sim Laptop Elite
    ],
    image: 'https://images.unsplash.com/photo-1535131749006-b7f58c99034b?auto=format&fit=crop&q=80&w=2070',
    tags: ['Premium', 'Entertainment', 'Luxury'],
    likes: 178,
    comments: 45,
    createdAt: '2024-01-19T10:00:00.000Z',
    updatedAt: '2024-01-19T10:00:00.000Z'
  }
];

export const useCommunityStore = create<CommunityStore>()(
  persist(
    (set) => ({
      builds: initialBuilds,
      addBuild: (buildData) => set((state) => ({
        builds: [
          {
            id: crypto.randomUUID(),
            ...buildData
          },
          ...state.builds
        ]
      })),
      likeBuild: (buildId) => set((state) => ({
        builds: state.builds.map(build =>
          build.id === buildId
            ? { ...build, likes: build.likes + 1 }
            : build
        )
      })),
      addComment: (buildId) => set((state) => ({
        builds: state.builds.map(build =>
          build.id === buildId
            ? { ...build, comments: build.comments + 1 }
            : build
        )
      }))
    }),
    {
      name: 'community-storage'
    }
  )
);