import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { ForumThread, ForumReply } from '../types/forum';

const testUser = {
  id: '1',
  username: 'testuser',
  email: 'test@example.com',
  joinedAt: '2024-01-01T00:00:00.000Z',
  postCount: 20
};

const initialThreads: ForumThread[] = [
  // Equipment & Setup Category
  {
    id: '1',
    title: 'GC3 vs Uneekor QED: In-depth Comparison',
    content: 'After testing both units extensively, here\'s my detailed comparison of the GC3 and Uneekor QED, covering accuracy, ease of use, and software compatibility.',
    author: testUser,
    createdAt: '2024-01-15T10:00:00.000Z',
    updatedAt: '2024-01-15T10:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['launch-monitors', 'equipment']
  },
  {
    id: '2',
    title: 'Best Short Throw Projectors for Limited Space',
    content: 'Looking for recommendations on short throw projectors under $2000. My ceiling height is 8ft and I have about 12ft of depth to work with.',
    author: testUser,
    createdAt: '2024-01-15T11:00:00.000Z',
    updatedAt: '2024-01-15T11:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['projectors', 'equipment']
  },
  {
    id: '3',
    title: 'Impact Screen Material Showdown',
    content: 'Comparing Carl\'s Premium, Elite, and Pro materials. Including pictures of ball marks after 1000 shots.',
    author: testUser,
    createdAt: '2024-01-15T12:00:00.000Z',
    updatedAt: '2024-01-15T12:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['screens', 'equipment']
  },
  {
    id: '4',
    title: 'Gaming PC Specs for Smooth Performance',
    content: 'What are the minimum and recommended PC specs for running modern golf sim software without frame drops?',
    author: testUser,
    createdAt: '2024-01-15T13:00:00.000Z',
    updatedAt: '2024-01-15T13:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['hardware', 'equipment']
  },
  {
    id: '5',
    title: 'Hitting Mat Durability Test Results',
    content: 'After 6 months of testing 5 different mats, here are my findings on durability, feel, and joint impact.',
    author: testUser,
    createdAt: '2024-01-15T14:00:00.000Z',
    updatedAt: '2024-01-15T14:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['equipment', 'hardware']
  },

  // Software & Games Category
  {
    id: '6',
    title: 'GSPro vs E6 Connect: 2024 Comparison',
    content: 'Detailed comparison of course quality, game modes, and multiplayer features between GSPro and E6 Connect.',
    author: testUser,
    createdAt: '2024-01-16T10:00:00.000Z',
    updatedAt: '2024-01-16T10:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['software', 'gaming']
  },
  {
    id: '7',
    title: 'Best Practice Games for Improvement',
    content: 'Collection of the most effective practice games and drills across different golf sim software platforms.',
    author: testUser,
    createdAt: '2024-01-16T11:00:00.000Z',
    updatedAt: '2024-01-16T11:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['gaming', 'software']
  },
  {
    id: '8',
    title: 'New Course Releases This Month',
    content: 'Roundup of all new golf courses released this month across major platforms.',
    author: testUser,
    createdAt: '2024-01-16T12:00:00.000Z',
    updatedAt: '2024-01-16T12:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['courses', 'gaming']
  },
  {
    id: '9',
    title: 'Online Tournaments Guide 2024',
    content: 'Complete guide to joining and hosting online tournaments in various golf sim platforms.',
    author: testUser,
    createdAt: '2024-01-16T13:00:00.000Z',
    updatedAt: '2024-01-16T13:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['gaming', 'software']
  },
  {
    id: '10',
    title: 'Shot Data Analysis Software Comparison',
    content: 'Comparing different software options for analyzing your shot data and tracking improvement.',
    author: testUser,
    createdAt: '2024-01-16T14:00:00.000Z',
    updatedAt: '2024-01-16T14:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['software', 'gaming']
  },

  // Build & Installation Category
  {
    id: '11',
    title: 'Complete DIY Enclosure Build Guide',
    content: 'Step-by-step guide to building a professional-quality enclosure for under $500.',
    author: testUser,
    createdAt: '2024-01-17T10:00:00.000Z',
    updatedAt: '2024-01-17T10:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['diy', 'build-guide']
  },
  {
    id: '12',
    title: 'Garage Conversion Tips & Tricks',
    content: 'Everything you need to know about converting your garage into a golf simulator space.',
    author: testUser,
    createdAt: '2024-01-17T11:00:00.000Z',
    updatedAt: '2024-01-17T11:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['setup', 'installation']
  },
  {
    id: '13',
    title: 'Projector Mounting Solutions',
    content: 'Different mounting options for ceiling and shelf mounting, with pros and cons of each.',
    author: testUser,
    createdAt: '2024-01-17T12:00:00.000Z',
    updatedAt: '2024-01-17T12:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['installation', 'build-guide']
  },
  {
    id: '14',
    title: 'Cable Management Strategies',
    content: 'How to keep your simulator setup clean and organized with proper cable management.',
    author: testUser,
    createdAt: '2024-01-17T13:00:00.000Z',
    updatedAt: '2024-01-17T13:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['setup', 'installation']
  },
  {
    id: '15',
    title: 'Lighting Setup Guide',
    content: 'Complete guide to lighting your simulator space for optimal visibility and camera performance.',
    author: testUser,
    createdAt: '2024-01-17T14:00:00.000Z',
    updatedAt: '2024-01-17T14:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['setup', 'build-guide']
  },

  // Troubleshooting & Support Category
  {
    id: '16',
    title: 'Common GC3 Error Codes Explained',
    content: 'Comprehensive list of GC3 error codes and how to resolve them.',
    author: testUser,
    createdAt: '2024-01-18T10:00:00.000Z',
    updatedAt: '2024-01-18T10:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['technical', 'support']
  },
  {
    id: '17',
    title: 'Calibration Guide for Better Accuracy',
    content: 'Step-by-step guide to calibrating your launch monitor for maximum accuracy.',
    author: testUser,
    createdAt: '2024-01-18T11:00:00.000Z',
    updatedAt: '2024-01-18T11:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['calibration', 'technical']
  },
  {
    id: '18',
    title: 'Fixing Input Lag Issues',
    content: 'Troubleshooting guide for reducing input lag in your simulator setup.',
    author: testUser,
    createdAt: '2024-01-18T12:00:00.000Z',
    updatedAt: '2024-01-18T12:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['technical', 'support']
  },
  {
    id: '19',
    title: 'Software Connectivity Problems Solved',
    content: 'Solutions for common connectivity issues between launch monitors and software.',
    author: testUser,
    createdAt: '2024-01-18T13:00:00.000Z',
    updatedAt: '2024-01-18T13:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['support', 'technical']
  },
  {
    id: '20',
    title: 'Impact Screen Repair Guide',
    content: 'How to repair minor damage to your impact screen and extend its lifespan.',
    author: testUser,
    createdAt: '2024-01-18T14:00:00.000Z',
    updatedAt: '2024-01-18T14:00:00.000Z',
    replies: 0,
    views: 0,
    tags: ['support', 'technical']
  }
];

export const useForumStore = create<ForumStore>()(
  persist(
    (set) => ({
      threads: initialThreads,
      replies: {},
      createThread: (threadData) => set((state) => {
        const newThread: ForumThread = {
          id: crypto.randomUUID(),
          ...threadData,
          createdAt: new Date().toISOString(),
          updatedAt: new Date().toISOString(),
          replies: 0,
          views: 0
        };
        return {
          threads: [newThread, ...state.threads]
        };
      }),
      updateThread: (threadId, updates) => set((state) => ({
        threads: state.threads.map(thread =>
          thread.id === threadId
            ? {
                ...thread,
                ...updates,
                updatedAt: new Date().toISOString()
              }
            : thread
        )
      })),
      deleteThread: (threadId) => set((state) => ({
        threads: state.threads.filter(thread => thread.id !== threadId),
        replies: {
          ...state.replies,
          [threadId]: undefined
        }
      })),
      createReply: (replyData) => set((state) => {
        const newReply: ForumReply = {
          id: crypto.randomUUID(),
          ...replyData,
          createdAt: new Date().toISOString(),
          updatedAt: new Date().toISOString()
        };

        const updatedThreads = state.threads.map(thread => 
          thread.id === replyData.threadId
            ? {
                ...thread,
                replies: thread.replies + 1,
                lastReply: {
                  author: replyData.author,
                  createdAt: newReply.createdAt
                }
              }
            : thread
        );

        return {
          threads: updatedThreads,
          replies: {
            ...state.replies,
            [replyData.threadId]: [
              ...(state.replies[replyData.threadId] || []),
              newReply
            ]
          }
        };
      }),
      incrementViews: (threadId) => set((state) => ({
        threads: state.threads.map(thread =>
          thread.id === threadId
            ? { ...thread, views: thread.views + 1 }
            : thread
        )
      }))
    }),
    {
      name: 'forum-storage'
    }
  )
);