import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { NotificationStore } from '../types/notification';

export const useNotificationStore = create<NotificationStore>()(
  persist(
    (set, get) => ({
      notifications: [],
      unreadCount: 0,
      markAsRead: (notificationId) => set((state) => {
        const notifications = state.notifications.map(notification =>
          notification.id === notificationId
            ? { ...notification, read: true }
            : notification
        );
        return {
          notifications,
          unreadCount: notifications.filter(n => !n.read).length
        };
      }),
      markAllAsRead: () => set((state) => ({
        notifications: state.notifications.map(n => ({ ...n, read: true })),
        unreadCount: 0
      })),
      addNotification: (notification) => set((state) => {
        const newNotification = {
          id: crypto.randomUUID(),
          createdAt: new Date().toISOString(),
          read: false,
          ...notification
        };
        return {
          notifications: [newNotification, ...state.notifications],
          unreadCount: state.unreadCount + 1
        };
      })
    }),
    {
      name: 'notifications-storage'
    }
  )
);