import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { PriceAlertStore } from '../types/priceAlert';

export const usePriceAlertStore = create<PriceAlertStore>()(
  persist(
    (set) => ({
      alerts: [],
      addAlert: (alert) => {
        const newAlert = {
          ...alert,
          id: crypto.randomUUID(),
          createdAt: new Date().toISOString(),
          isActive: true
        };
        set((state) => ({
          alerts: [...state.alerts, newAlert]
        }));
      },
      removeAlert: (alertId) => {
        set((state) => ({
          alerts: state.alerts.filter((alert) => alert.id !== alertId)
        }));
      },
      toggleAlert: (alertId) => {
        set((state) => ({
          alerts: state.alerts.map((alert) =>
            alert.id === alertId
              ? { ...alert, isActive: !alert.isActive }
              : alert
          )
        }));
      }
    }),
    {
      name: 'price-alerts-storage'
    }
  )
);