import { Product } from '../types';
import { PriceAlert } from '../types/priceAlert';
import { useNotificationStore } from '../stores/notificationStore';

export function checkPriceAlerts(product: Product, alerts: PriceAlert[]) {
  const { addNotification } = useNotificationStore.getState();
  
  alerts
    .filter(alert => alert.isActive && alert.productId === product.id)
    .forEach(alert => {
      const shouldNotify = 
        (alert.type === 'decrease' && product.price <= alert.targetPrice) ||
        (alert.type === 'increase' && product.price >= alert.targetPrice);

      if (shouldNotify) {
        // Add notification
        addNotification({
          userId: alert.userId,
          threadId: '', // Not forum related
          replyId: '', // Not forum related
          title: `Price ${alert.type === 'decrease' ? 'Drop' : 'Increase'} Alert`,
          content: `${product.name} is now $${product.price.toLocaleString()}`,
          author: {
            username: 'System',
          }
        });

        // Send email (mock implementation)
        console.log(`Sending email for price alert: ${product.name}`);
      }
    });
}